@@ -25,7 +25,7 @@ struct pod {
 using tuple_t = cuda::std::tuple<int, pod, unsigned long long>;
 
 template<int N>
-struct write
+struct Write
 {
     using async = cuda::std::false_type;
 
@@ -40,7 +40,7 @@ struct write
 };
 
 template<int N>
-struct read
+struct Read
 {
     using async = cuda::std::false_type;
 
@@ -55,10 +55,10 @@ struct read
 };
 
 using w_r_w_r = performer_list<
-  write<10>,
-  read<10>,
-  write<30>,
-  read<30>
+  Write<10>,
+  Read<10>,
+  Write<30>,
+  Read<30>
 >;
 
 void kernel_invoker()
